
EAPI void
elm_entry_scrollable_set(Elm_Entry *obj, Eina_Bool scroll)
{
   elm_obj_entry_scrollable_set(obj, scroll);
}

EAPI Eina_Bool
elm_entry_scrollable_get(const Elm_Entry *obj)
{
   return elm_obj_entry_scrollable_get(obj);
}

EAPI void
elm_entry_input_panel_show_on_demand_set(Elm_Entry *obj, Eina_Bool ondemand)
{
   elm_obj_entry_input_panel_show_on_demand_set(obj, ondemand);
}

EAPI Eina_Bool
elm_entry_input_panel_show_on_demand_get(const Elm_Entry *obj)
{
   return elm_obj_entry_input_panel_show_on_demand_get(obj);
}

EAPI void
elm_entry_context_menu_disabled_set(Elm_Entry *obj, Eina_Bool disabled)
{
   elm_obj_entry_context_menu_disabled_set(obj, disabled);
}

EAPI Eina_Bool
elm_entry_context_menu_disabled_get(const Elm_Entry *obj)
{
   return elm_obj_entry_context_menu_disabled_get(obj);
}

EAPI void
elm_entry_cnp_mode_set(Elm_Entry *obj, Elm_Cnp_Mode cnp_mode)
{
   elm_obj_entry_cnp_mode_set(obj, cnp_mode);
}

EAPI Elm_Cnp_Mode
elm_entry_cnp_mode_get(const Elm_Entry *obj)
{
   return elm_obj_entry_cnp_mode_get(obj);
}

EAPI void
elm_entry_file_text_format_set(Elm_Entry *obj, Elm_Text_Format format)
{
   elm_obj_entry_file_text_format_set(obj, format);
}

EAPI void
elm_entry_input_panel_language_set(Elm_Entry *obj, Elm_Input_Panel_Lang lang)
{
   elm_obj_entry_input_panel_language_set(obj, lang);
}

EAPI Elm_Input_Panel_Lang
elm_entry_input_panel_language_get(const Elm_Entry *obj)
{
   return elm_obj_entry_input_panel_language_get(obj);
}

EAPI void
elm_entry_selection_handler_disabled_set(Elm_Entry *obj, Eina_Bool disabled)
{
   elm_obj_entry_selection_handler_disabled_set(obj, disabled);
}

EAPI void
elm_entry_input_panel_layout_variation_set(Elm_Entry *obj, int variation)
{
   elm_obj_entry_input_panel_layout_variation_set(obj, variation);
}

EAPI int
elm_entry_input_panel_layout_variation_get(const Elm_Entry *obj)
{
   return elm_obj_entry_input_panel_layout_variation_get(obj);
}

EAPI void
elm_entry_autocapital_type_set(Elm_Entry *obj, Elm_Autocapital_Type autocapital_type)
{
   elm_obj_entry_autocapital_type_set(obj, autocapital_type);
}

EAPI Elm_Autocapital_Type
elm_entry_autocapital_type_get(const Elm_Entry *obj)
{
   return elm_obj_entry_autocapital_type_get(obj);
}

EAPI void
elm_entry_editable_set(Elm_Entry *obj, Eina_Bool editable)
{
   elm_obj_entry_editable_set(obj, editable);
}

EAPI Eina_Bool
elm_entry_editable_get(const Elm_Entry *obj)
{
   return elm_obj_entry_editable_get(obj);
}

EAPI void
elm_entry_anchor_hover_style_set(Elm_Entry *obj, const char *style)
{
   elm_obj_entry_anchor_hover_style_set(obj, style);
}

EAPI const char *
elm_entry_anchor_hover_style_get(const Elm_Entry *obj)
{
   return elm_obj_entry_anchor_hover_style_get(obj);
}

EAPI void
elm_entry_single_line_set(Elm_Entry *obj, Eina_Bool single_line)
{
   elm_obj_entry_single_line_set(obj, single_line);
}

EAPI Eina_Bool
elm_entry_single_line_get(const Elm_Entry *obj)
{
   return elm_obj_entry_single_line_get(obj);
}

EAPI void
elm_entry_password_set(Elm_Entry *obj, Eina_Bool password)
{
   elm_obj_entry_password_set(obj, password);
}

EAPI Eina_Bool
elm_entry_password_get(const Elm_Entry *obj)
{
   return elm_obj_entry_password_get(obj);
}

EAPI void
elm_entry_input_panel_return_key_disabled_set(Elm_Entry *obj, Eina_Bool disabled)
{
   elm_obj_entry_input_panel_return_key_disabled_set(obj, disabled);
}

EAPI Eina_Bool
elm_entry_input_panel_return_key_disabled_get(const Elm_Entry *obj)
{
   return elm_obj_entry_input_panel_return_key_disabled_get(obj);
}

EAPI void
elm_entry_autosave_set(Elm_Entry *obj, Eina_Bool auto_save)
{
   elm_obj_entry_autosave_set(obj, auto_save);
}

EAPI Eina_Bool
elm_entry_autosave_get(const Elm_Entry *obj)
{
   return elm_obj_entry_autosave_get(obj);
}

EAPI void
elm_entry_anchor_hover_parent_set(Elm_Entry *obj, Efl_Canvas_Object *parent)
{
   elm_obj_entry_anchor_hover_parent_set(obj, parent);
}

EAPI Efl_Canvas_Object *
elm_entry_anchor_hover_parent_get(const Elm_Entry *obj)
{
   return elm_obj_entry_anchor_hover_parent_get(obj);
}

EAPI void
elm_entry_prediction_allow_set(Elm_Entry *obj, Eina_Bool prediction)
{
   elm_obj_entry_prediction_allow_set(obj, prediction);
}

EAPI Eina_Bool
elm_entry_prediction_allow_get(const Elm_Entry *obj)
{
   return elm_obj_entry_prediction_allow_get(obj);
}

EAPI void
elm_entry_input_hint_set(Elm_Entry *obj, Elm_Input_Hints hints)
{
   elm_obj_entry_input_hint_set(obj, hints);
}

EAPI Elm_Input_Hints
elm_entry_input_hint_get(const Elm_Entry *obj)
{
   return elm_obj_entry_input_hint_get(obj);
}

EAPI void
elm_entry_input_panel_layout_set(Elm_Entry *obj, Elm_Input_Panel_Layout layout)
{
   elm_obj_entry_input_panel_layout_set(obj, layout);
}

EAPI Elm_Input_Panel_Layout
elm_entry_input_panel_layout_get(const Elm_Entry *obj)
{
   return elm_obj_entry_input_panel_layout_get(obj);
}

EAPI void
elm_entry_input_panel_return_key_type_set(Elm_Entry *obj, Elm_Input_Panel_Return_Key_Type return_key_type)
{
   elm_obj_entry_input_panel_return_key_type_set(obj, return_key_type);
}

EAPI Elm_Input_Panel_Return_Key_Type
elm_entry_input_panel_return_key_type_get(const Elm_Entry *obj)
{
   return elm_obj_entry_input_panel_return_key_type_get(obj);
}

EAPI void
elm_entry_input_panel_enabled_set(Elm_Entry *obj, Eina_Bool enabled)
{
   elm_obj_entry_input_panel_enabled_set(obj, enabled);
}

EAPI Eina_Bool
elm_entry_input_panel_enabled_get(const Elm_Entry *obj)
{
   return elm_obj_entry_input_panel_enabled_get(obj);
}

EAPI void
elm_entry_line_wrap_set(Elm_Entry *obj, Elm_Wrap_Type wrap)
{
   elm_obj_entry_line_wrap_set(obj, wrap);
}

EAPI Elm_Wrap_Type
elm_entry_line_wrap_get(const Elm_Entry *obj)
{
   return elm_obj_entry_line_wrap_get(obj);
}

EAPI void
elm_entry_cursor_pos_set(Elm_Entry *obj, int pos)
{
   elm_obj_entry_cursor_pos_set(obj, pos);
}

EAPI int
elm_entry_cursor_pos_get(const Elm_Entry *obj)
{
   return elm_obj_entry_cursor_pos_get(obj);
}

EAPI void
elm_entry_icon_visible_set(Elm_Entry *obj, Eina_Bool setting)
{
   elm_obj_entry_icon_visible_set(obj, setting);
}

EAPI void
elm_entry_cursor_line_end_set(Elm_Entry *obj)
{
   elm_obj_entry_cursor_line_end_set(obj);
}

EAPI void
elm_entry_select_region_set(Elm_Entry *obj, int start, int end)
{
   elm_obj_entry_select_region_set(obj, start, end);
}

EAPI void
elm_entry_select_region_get(const Elm_Entry *obj, int *start, int *end)
{
   elm_obj_entry_select_region_get(obj, start, end);
}

EAPI void
elm_entry_input_panel_return_key_autoenabled_set(Elm_Entry *obj, Eina_Bool enabled)
{
   elm_obj_entry_input_panel_return_key_autoenabled_set(obj, enabled);
}

EAPI void
elm_entry_end_visible_set(Elm_Entry *obj, Eina_Bool setting)
{
   elm_obj_entry_end_visible_set(obj, setting);
}

EAPI void
elm_entry_cursor_begin_set(Elm_Entry *obj)
{
   elm_obj_entry_cursor_begin_set(obj);
}

EAPI void
elm_entry_cursor_line_begin_set(Elm_Entry *obj)
{
   elm_obj_entry_cursor_line_begin_set(obj);
}

EAPI void
elm_entry_cursor_end_set(Elm_Entry *obj)
{
   elm_obj_entry_cursor_end_set(obj);
}

EAPI Efl_Canvas_Object *
elm_entry_textblock_get(const Elm_Entry *obj)
{
   return elm_obj_entry_textblock_get(obj);
}

EAPI Eina_Bool
elm_entry_cursor_geometry_get(const Elm_Entry *obj, int *x, int *y, int *w, int *h)
{
   return elm_obj_entry_textblock_cursor_geometry_get(obj, x, y, w, h);
}

EAPI void *
elm_entry_imf_context_get(const Elm_Entry *obj)
{
   return elm_obj_entry_imf_context_get(obj);
}

EAPI Eina_Bool
elm_entry_cursor_is_format_get(const Elm_Entry *obj)
{
   return elm_obj_entry_cursor_is_format_get(obj);
}

EAPI char *
elm_entry_cursor_content_get(const Elm_Entry *obj)
{
   return elm_obj_entry_textblock_cursor_content_get(obj);
}

EAPI const char *
elm_entry_selection_get(const Elm_Entry *obj)
{
   return elm_obj_entry_selection_get(obj);
}

EAPI Eina_Bool
elm_entry_cursor_is_visible_format_get(const Elm_Entry *obj)
{
   return elm_obj_entry_cursor_is_visible_format_get(obj);
}

EAPI void
elm_entry_select_allow_set(Elm_Entry *obj, Eina_Bool allow)
{
   elm_obj_entry_select_allow_set(obj, allow);
}

EAPI Eina_Bool
elm_entry_select_allow_get(const Elm_Entry *obj)
{
   return elm_obj_entry_select_allow_get(obj);
}

EAPI Eina_Bool
elm_entry_cursor_prev(Elm_Entry *obj)
{
   return elm_obj_entry_cursor_prev(obj);
}

EAPI void
elm_entry_text_style_user_pop(Elm_Entry *obj)
{
   elm_obj_entry_text_style_user_pop(obj);
}

EAPI void
elm_entry_item_provider_prepend(Elm_Entry *obj, Elm_Entry_Item_Provider_Cb func, void *data)
{
   elm_obj_entry_item_provider_prepend(obj, func, data);
}

EAPI void
elm_entry_input_panel_show(Elm_Entry *obj)
{
   elm_obj_entry_input_panel_show(obj);
}

EAPI void
elm_entry_imf_context_reset(Elm_Entry *obj)
{
   elm_obj_entry_imf_context_reset(obj);
}

EAPI void
elm_entry_anchor_hover_end(Elm_Entry *obj)
{
   elm_obj_entry_anchor_hover_end(obj);
}

EAPI void
elm_entry_cursor_selection_begin(Elm_Entry *obj)
{
   elm_obj_entry_cursor_selection_begin(obj);
}

EAPI Eina_Bool
elm_entry_cursor_down(Elm_Entry *obj)
{
   return elm_obj_entry_cursor_down(obj);
}

EAPI void
elm_entry_file_save(Elm_Entry *obj)
{
   elm_obj_entry_file_save(obj);
}

EAPI void
elm_entry_selection_copy(Elm_Entry *obj)
{
   elm_obj_entry_selection_copy(obj);
}

EAPI void
elm_entry_text_style_user_push(Elm_Entry *obj, const char *style)
{
   elm_obj_entry_text_style_user_push(obj, style);
}

EAPI void
elm_entry_item_provider_remove(Elm_Entry *obj, Elm_Entry_Item_Provider_Cb func, void *data)
{
   elm_obj_entry_item_provider_remove(obj, func, data);
}

EAPI const char *
elm_entry_text_style_user_peek(const Elm_Entry *obj)
{
   return elm_obj_entry_text_style_user_peek(obj);
}

EAPI void
elm_entry_context_menu_clear(Elm_Entry *obj)
{
   elm_obj_entry_context_menu_clear(obj);
}

EAPI Eina_Bool
elm_entry_cursor_up(Elm_Entry *obj)
{
   return elm_obj_entry_cursor_up(obj);
}

EAPI void
elm_entry_entry_insert(Elm_Entry *obj, const char *entry)
{
   elm_obj_entry_insert(obj, entry);
}

EAPI void
elm_entry_input_panel_imdata_set(Elm_Entry *obj, const void *data, int len)
{
   elm_obj_entry_input_panel_imdata_set(obj, data, len);
}

EAPI void
elm_entry_input_panel_imdata_get(const Elm_Entry *obj, void *data, int *len)
{
   elm_obj_entry_input_panel_imdata_get(obj, data, len);
}

EAPI void
elm_entry_selection_paste(Elm_Entry *obj)
{
   elm_obj_entry_selection_paste(obj);
}

EAPI Eina_Bool
elm_entry_cursor_next(Elm_Entry *obj)
{
   return elm_obj_entry_cursor_next(obj);
}

EAPI void
elm_entry_select_none(Elm_Entry *obj)
{
   elm_obj_entry_select_none(obj);
}

EAPI void
elm_entry_input_panel_hide(Elm_Entry *obj)
{
   elm_obj_entry_input_panel_hide(obj);
}

EAPI void
elm_entry_select_all(Elm_Entry *obj)
{
   elm_obj_entry_select_all(obj);
}

EAPI void
elm_entry_cursor_selection_end(Elm_Entry *obj)
{
   elm_obj_entry_cursor_selection_end(obj);
}

EAPI void
elm_entry_selection_cut(Elm_Entry *obj)
{
   elm_obj_entry_selection_cut(obj);
}

EAPI Eina_Bool
elm_entry_is_empty(const Elm_Entry *obj)
{
   return elm_obj_entry_is_empty(obj);
}

EAPI void
elm_entry_markup_filter_remove(Elm_Entry *obj, Elm_Entry_Filter_Cb func, void *data)
{
   elm_obj_entry_markup_filter_remove(obj, func, data);
}

EAPI void
elm_entry_item_provider_append(Elm_Entry *obj, Elm_Entry_Item_Provider_Cb func, void *data)
{
   elm_obj_entry_item_provider_append(obj, func, data);
}

EAPI void
elm_entry_markup_filter_append(Elm_Entry *obj, Elm_Entry_Filter_Cb func, void *data)
{
   elm_obj_entry_markup_filter_append(obj, func, data);
}

EAPI void
elm_entry_entry_append(Elm_Entry *obj, const char *str)
{
   elm_obj_entry_append(obj, str);
}

EAPI void
elm_entry_context_menu_item_add(Elm_Entry *obj, const char *label, const char *icon_file, Elm_Icon_Type icon_type, Evas_Smart_Cb func, const void *data)
{
   elm_obj_entry_context_menu_item_add(obj, label, icon_file, icon_type, func, data);
}

EAPI void
elm_entry_markup_filter_prepend(Elm_Entry *obj, Elm_Entry_Filter_Cb func, void *data)
{
   elm_obj_entry_markup_filter_prepend(obj, func, data);
}

EAPI void
elm_entry_prediction_hint_set(Elm_Entry *obj, const char *prediction_hint)
{
   elm_obj_entry_prediction_hint_set(obj, prediction_hint);
}

EAPI Eina_Bool
elm_entry_prediction_hint_hash_set(Elm_Entry *obj, const char *key, const char *value)
{
   return elm_obj_entry_prediction_hint_hash_set(obj, key, value);
}

EAPI Eina_Bool
elm_entry_prediction_hint_hash_del(Elm_Entry *obj, const char *key)
{
   return elm_obj_entry_prediction_hint_hash_del(obj, key);
}
